@@ -5,14 +5,6 @@
     $Id: exbin.cxx,v 1.5 2008-10-07 11:06:25 tat Exp $
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 /** \example exbin.cc
  *  extract a Part based on command line parameters
  *  more info on:
@@ -108,7 +100,7 @@ static bool is_known_mechanism(const string& mechanism)
 void decode_bin(const MimeEntity& me)
 {
     const ContentTransferEncoding& cte = me.header().contentTransferEncoding();
-    const ContentDisposition& cd = me.header().contentDisposition();
+    // const ContentDisposition& cd = me.header().contentDisposition();
 
     if(is_known_mechanism(cte.mechanism()))
     {
@@ -133,17 +125,18 @@ void decode_bin(const MimeEntity& me)
         }
         ostreambuf_iterator<char> oi(of);
         istring enc_algo = cte.mechanism();
-        if(enc_algo == "base64")
+        if(enc_algo == ContentTransferEncoding::base64)
         {
             Base64::Decoder b64;
             g_decoded++;
             decode(me.body().begin(), me.body().end(), b64 ,oi);
-        } else if (enc_algo == "quoted-printable") {
+        } else if (enc_algo == ContentTransferEncoding::quoted_printable) {
             QP::Decoder qp;
             g_decoded++;
             decode(me.body().begin(), me.body().end(), qp, oi);
-        } else if (enc_algo == "8bit" || enc_algo == "7bit" || 
-                enc_algo == "binary") {
+        } else if (enc_algo == ContentTransferEncoding::eightbit || 
+                enc_algo == ContentTransferEncoding::sevenbit || 
+                enc_algo == ContentTransferEncoding::binary) {
             copy(me.body().begin(), me.body().end(), oi);
         } else {
             cerr << "ERR: unknown encoding algorithm "
