@@ -15,4 +15,13 @@
 #define HAVE_SYS_TYPES_H 1
 
 #define PACKAGE "mimetic"
-#define VERSION "0.9.6rc2"
+#define VERSION "0.9.7"
+
+
+typedef __int16 int16_t;
+typedef unsigned __int16 uint16_t;
+typedef __int32 int32_t;
+typedef unsigned __int32 uint32_t;
+typedef __int64 int64_t;
+typedef unsigned __int64 uint64_t;
+
