@@ -4,15 +4,6 @@
 
     $Id: contenttransferencoding.cxx,v 1.3 2008-10-07 11:06:25 tat Exp $
  ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 #include <mimetic/contenttransferencoding.h>
 
 namespace mimetic
@@ -20,6 +11,11 @@ namespace mimetic
 using namespace std;
 
 const char ContentTransferEncoding::label[] = "Content-Transfer-Encoding";
+const char ContentTransferEncoding::base64[] = "base64";
+const char ContentTransferEncoding::quoted_printable[] = "quoted-printable";
+const char ContentTransferEncoding::binary[] = "binary";
+const char ContentTransferEncoding::sevenbit[] = "7bit";
+const char ContentTransferEncoding::eightbit[] = "8bit";
 
 ContentTransferEncoding::ContentTransferEncoding()
 {
